"use strict";

/* eslint-disable no-console */

import { createHighlighterCore, normalizeTheme } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import githubDark from 'shiki/dist/themes/github-dark.mjs';

// Import languages
import css from 'shiki/dist/langs/css.mjs';
import html from 'shiki/dist/langs/html.mjs';
import javascript from 'shiki/dist/langs/javascript.mjs';
import json from 'shiki/dist/langs/json.mjs';
import markdown from 'shiki/dist/langs/markdown.mjs';
import php from 'shiki/dist/langs/php.mjs';
import tsx from 'shiki/dist/langs/tsx.mjs';
import typescript from 'shiki/dist/langs/typescript.mjs';
const DEBUG = true;
function log(message, ...args) {
  if (DEBUG) {
    console.log(`[ShikiContext] ${message}`, ...args);
  }
}
// Define raw languages with proper typing
const rawLanguages = {
  typescript,
  javascript,
  json,
  html,
  css,
  markdown,
  tsx,
  php,
  plaintext: {
    id: 'plaintext',
    scopeName: 'source.plaintext',
    grammar: {
      patterns: [{
        match: '.*',
        name: 'text.plain'
      }]
    }
  }
};
let highlighterInstance = null;

// Process raw languages into LanguageRegistrations
function processLanguages() {
  return Object.entries(rawLanguages).map(([key, lang]) => {
    // Ensure we have all required fields with proper fallbacks
    const registration = {
      name: lang.id || key,
      scopeName: lang.scopeName || `source.${key}`,
      patterns: lang.patterns || lang.grammar?.patterns || [],
      repository: lang.repository || lang.grammar?.repository || {},
      aliases: lang.aliases || [],
      embeddedLangs: lang.embeddedLanguages || []
    };
    log(`Processing language: ${registration.name}`, registration);
    return registration;
  });
}
log('TypeScript language structure:', typescript);
export async function getHighlighter() {
  if (highlighterInstance) {
    log('Returning cached highlighter instance');
    return highlighterInstance;
  }
  try {
    log('Creating new highlighter instance...');

    // Create engine
    const engine = createJavaScriptRegexEngine();

    // Process languages
    const languages = processLanguages();

    // Create highlighter
    highlighterInstance = await createHighlighterCore({
      themes: [normalizeTheme(githubDark)],
      langs: languages,
      engine
    });
    if (!highlighterInstance) {
      throw new Error('Failed to create highlighter instance');
    }
    const loadedLangs = highlighterInstance.getLoadedLanguages();
    log('Successfully loaded languages:', loadedLangs);
    return highlighterInstance;
  } catch (error) {
    log('Error creating highlighter:', error);
    throw error;
  }
}
export function isValidLanguage(lang) {
  const normalized = lang.toLowerCase();
  return Object.keys(rawLanguages).includes(normalized);
}
export function getSafeLanguage(lang) {
  const normalized = lang.toLowerCase();
  if (isValidLanguage(normalized)) {
    return normalized;
  }
  log(`Warning: Unsupported language '${lang}', falling back to plaintext`);
  return 'plaintext';
}
//# sourceMappingURL=SyntaxContext.js.map